@@ -5,5 +5,5 @@ normalize <- function(x){
   norm <- sqrt(sum(x^2))
   
   normvec <- x/norm
-  normvec
+  return(normvec)
 }
\ No newline at end of file
