@@ -35,15 +35,15 @@ plot_neighbors <- function(x,n,connect.lines="all",
   
   if(!(dims %in% 2:3)){stop("Please set dim to 2 or 3")}
   
-  if(class(tvectors) == "data.frame"){
+  if(is.data.frame(tvectors)){
     tvectors <- as.matrix(tvectors)
-  }else if(class(tvectors) == "textmatrix"){
+  }else if("textmatrix" %in% class(tvectors)){
     tvectors <- matrix(tvectors,
                        nrow=nrow(tvectors),ncol=ncol(tvectors),
                        dimnames=list(rownames(tvectors),colnames(tvectors)))
   }
   
-  if(class(tvectors) == "matrix"){
+  if(is.matrix(tvectors)){
     
     if(class(x) == "factor"){
       x <- as.character(x)
